;+
; NAME:
;	rdpoint
; PURPOSE: (one line)
;	Read a raw (PC format) binary pointing data file as produced by MOVE.
; DESCRIPTION:
; CATEGORY:
; CALLING SEQUENCE:
;	rdpoint,filename,raobs,decobs,ratrue,dectrue,sidtime
; INPUTS:
;	filename - String containing the name of file to read.
; OPTIONAL INPUT PARAMETERS:
; KEYWORD PARAMETERS:
; OUTPUTS:
;	raobs   - Observed right ascension in degrees.
;	decobs  - Observed declination in degrees.
;	ratrue  - Catalog right ascension in degrees.
;	dectrue - Catalog declination in degrees.
;	sidtime - Local sidereal time at the time of observations (degrees).
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;	2/10/93 - Written by Marc W. Buie, Lowell Observatory
;-

function x_getint,ptr  ; Byte swaps a 2 byte integer.
byteorder,ptr,/sswap
return,fix(ptr,0,1)
end

function x_getdbl,ptr  ; End for end swaps a double precision number.
tmp=ptr(0)
ptr(0)=ptr(7)
ptr(7)=tmp
tmp=ptr(1)
ptr(1)=ptr(6)
ptr(6)=tmp
tmp=ptr(2)
ptr(2)=ptr(5)
ptr(5)=tmp
tmp=ptr(3)
ptr(3)=ptr(4)
ptr(4)=tmp
return,double(ptr,0,1)
end

pro rdpoint,filename,raobs,decobs,ratrue,dectrue,sidtime

openr,lun,filename,/get_lun
rec=bytarr(49)
readu,lun,rec
nobs=x_getint(rec(0:1))
nobs=nobs(0)
print,nobs,' objects in file.'
for i=0,nobs-1 do begin
   readu,lun,rec
   if i eq 0 then begin
      raobs  = x_getdbl(rec(0:7))
      decobs = x_getdbl(rec(8:15))
      ratrue = x_getdbl(rec(16:23))
      dectrue= x_getdbl(rec(24:31))
      sidtime= x_getdbl(rec(32:39))
   endif else begin
      raobs  = [raobs,x_getdbl(rec(0:7))]
      decobs = [decobs,x_getdbl(rec(8:15))]
      ratrue = [ratrue,x_getdbl(rec(16:23))]
      dectrue= [dectrue,x_getdbl(rec(24:31))]
      sidtime= [sidtime,x_getdbl(rec(32:39))]
   endelse
endfor
free_lun,lun

raobs   = raobs   * 15.0d0
ratrue  = ratrue  * 15.0d0
sidtime = sidtime * 15.0d0

end
